---
title: "ART Notebooks"
sidebarTitle: "Notebooks"
description: "Use ART to train agents for many different tasks."
icon: "book"
---

<div className="full-width">

| Agent Task          | Notebook                                                                                                                                         | Description                                         | Performance                                                                                                                                                                                                                                                      |
| ------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------ | --------------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| **ART•E [Serverless]**   | [🏋️&nbsp;Train&nbsp;agent](https://colab.research.google.com/github/openpipe/art-notebooks/blob/main/examples/art-e.ipynb)                       | Qwen3 14B learns to search emails using RULER     | <a href="https://github.com/OpenPipe/ART/blob/main/dev/art-e/art_e/evaluate/display_benchmarks.ipynb"><img src="https://github.com/OpenPipe/ART/raw/main/assets/benchmarks/email_agent/accuracy-training-progress.svg" width="72" style={{margin: "0"}} /></a>   |
| **2048 [Serverless]** | [🏋️&nbsp;Train&nbsp;agent](https://colab.research.google.com/github/openpipe/art-notebooks/blob/main/examples/2048/2048.ipynb)                   | Qwen3 14B learns to play 2048                     | <a href="https://github.com/OpenPipe/ART/blob/main/examples/2048/display_benchmarks.ipynb"><img src="https://github.com/OpenPipe/ART/raw/main/assets/benchmarks/2048/accuracy-training-progress.svg" width="72" style={{margin: "0"}} /></a>                     |
| **ART•E LangGraph** | [🏋️&nbsp;Train&nbsp;agent](https://colab.research.google.com/github/openpipe/art-notebooks/blob/main/examples/langgraph/art-e-langgraph.ipynb)   | Qwen2.5 7B learns to search emails using LangGraph | [Link coming soon]                                                                                                                                                                                                                                               |
| **MCP•RL**          | [🏋️&nbsp;Train&nbsp;agent](https://colab.research.google.com/github/openpipe/art-notebooks/blob/main/examples/mcp-rl/mcp-rl.ipynb)               | Qwen2.5 3B masters the NWS MCP server              | [Link coming soon]                                                                                                                                                                                                                                               |
| **Temporal Clue**   | [🏋️&nbsp;Train&nbsp;agent](https://colab.research.google.com/github/openpipe/art-notebooks/blob/main/examples/temporal_clue/temporal-clue.ipynb) | Qwen2.5 7B learns to solve Temporal Clue           | [Link coming soon]                                                                                                                                                                                                                                               |
| **Tic Tac Toe**     | [🏋️&nbsp;Train&nbsp;agent](https://colab.research.google.com/github/openpipe/art-notebooks/blob/main/examples/tic_tac_toe/tic-tac-toe.ipynb)     | Qwen2.5 3B learns to play Tic Tac Toe              | <a href="https://github.com/OpenPipe/ART/blob/main/examples/tic_tac_toe/display-benchmarks.ipynb"><img src="https://github.com/OpenPipe/ART/raw/main/assets/benchmarks/tic-tac-toe-local/accuracy-training-progress.svg" width="72" style={{margin: "0"}} /></a> |
| **Codenames**       | [🏋️&nbsp;Train&nbsp;agent](https://colab.research.google.com/github/openpipe/art-notebooks/blob/main/examples/codenames/Codenames_RL.ipynb)      | Qwen2.5 3B learns to play Codenames                | <a href="https://github.com/OpenPipe/art-notebooks/blob/main/examples/codenames/Codenames_RL.ipynb"><img src="https://github.com/OpenPipe/ART/raw/main/assets/benchmarks/codenames/win_rate_over_time.png" width="72" style={{margin: "0"}} /></a>               |
| **AutoRL [RULER]**  | [🏋️&nbsp;Train&nbsp;agent](https://colab.research.google.com/github/openpipe/art-notebooks/blob/main/examples/auto_rl.ipynb)                     | Train Qwen2.5 7B to master any task                | [Link coming soon]                                                                                                                                                                                                                                               |

</div>
